pub struct QueryArgs {
pub last_game: bool,
pub last_variation: bool,
pub last_node: bool,
pub game_number: u64,
pub variation: u64,
}Fields
last_game: boolPrint the index of the last game.
last_variation: boolPrint the index of the last variation in the selected game.
last_node: boolPrint the index of the last node in the selected variation.
game_number: u64Game number to query.
variation: u64Variation number to query.
Implementations